import sys
import os
modules_path = '../../../modules/'
if os.path.exists(modules_path):
    sys.path.insert(1, modules_path)

from db.entities import Location, PopularLocation, UserCluster
from typing import List, Dict, Tuple
from db.repository import Repository
from processing.clusterer import Clusterer


DEBUG = False

repo = Repository()


def run_location_clustering():
    user_clusterer = Clusterer()

    all_location_traces = repo.get_agi_locations()

    cluster_result = user_clusterer.cluster_locations(
        [l.to_serializable_dict() for l in all_location_traces])

    clusters = [UserCluster(key, value)
                for key, value in cluster_result.items()]

    store_user_clusters(clusters)


def run_time_clustering():
    all_location_traces = repo.get_agi_locations()

    user_clusterer = Clusterer(epsilon=10**5.8)

    user_clusterer.cluster_times([l.to_serializable_dict() for l in all_location_traces])


def store_user_clusters(user_clusters: List[UserCluster]):
    if DEBUG:
        print(user_clusters)
        return

    for c in user_clusters:
        repo.add_user_cluster(c)


if __name__ == "__main__":
    run_time_clustering()
